# Jinja2 Templates Folder

## Context

### project.name

### project.license_spdx

### project.status

### project.language

### project.audience

### project.topic

### project.homepage

### project.download

### project.copyright_head

### project.author

### project.email

### project.summary
